/**
 * File: Registration.java
 * Author: Ken-Yinn Chung, Edision Chindrawaly
 * Date: 2.17.2001
 */

import java.sql.*;
import java.io.*;
import java.util.*;
import java.lang.*;
import javax.servlet.*;
import javax.servlet.http.*;


public class Registration extends HttpServlet {
    Connection dbConn;

    // Make connection to database
    public void init() throws ServletException {
	String driver = "org.gjt.mm.mysql.Driver";
	String url = "jdbc:mysql://richese.csci.unt.edu/chung";
	String user = "chung";
	String pwd = "chung";

	try{
	    Class.forName(driver);
	    dbConn = DriverManager.getConnection(url, user, pwd);
	} catch(ClassNotFoundException e) {
	    System.out.println("Database driver class not found.");
	    System.out.println(e);
	    throw new UnavailableException(this,
					   "JDBC driver class not found");
	} catch(SQLException e) {
	    System.out.println("Error connecting to the database.");
	    System.out.println(e);
	    throw new UnavailableException(this,
					   "Cannot connect to the database");
	}
    } // end init


    public void doPost(HttpServletRequest request, HttpServletResponse response)
	throws ServletException, IOException {

	ResultSet rs;
	Statement stmt;
	StringBuffer sql = new StringBuffer(512);
	StringBuffer member = new StringBuffer(512);
	StringBuffer contact = new StringBuffer(512);
	StringBuffer has = new StringBuffer(512);
	PrintWriter out = response.getWriter();
	Vector missing = new Vector();
	int msize;
	boolean err = false;

	response.setContentType("text/html");

	// Get field values and check their validitions
	String firstName = request.getParameter("firstName");
	if (firstName.length() == 0)
	    missing.add("First Name");

	String lastName = request.getParameter("lastName");
	if (lastName.length() == 0)
	    missing.add("Last Name");

	String email = request.getParameter("email");
	if (email.length() == 0)
	    missing.add("E-mail Address");

	String dob = request.getParameter("DOB_Year");
	if (dob.length() == 0)
	    missing.add("Date of Birth: Year");
	else if (request.getParameter("DOB_Month").length() == 0)
	    missing.add("Date of Birth: Month");
	else {
	    dob = dob + "-" + request.getParameter("DOB_Month");
	    if (request.getParameter("DOB_Day").length() == 0)
		missing.add("Date of Birth: Day");
	    else
		dob = dob + "-" + request.getParameter("DOB_Day");
	}

	String phone = request.getParameter("phone");
	if (phone.length() == 0)
	    missing.add("Telephone");

	String country = request.getParameter("country");
	if (country.length() == 0)
	    missing.add("Country");

	String zip = request.getParameter("zip");
	if (country.compareTo("United States") == 0 && zip.length() == 0)
	    missing.add("Zip Code");

	String state = request.getParameter("state");
	if (country.compareTo("United States") == 0 &&
	    state.compareTo("other") == 0) {
	    if (request.getParameter("state_other").length() == 0)
		missing.add("State");
	    else {
		err = true;
	    }
	}
	else if (state.compareTo("other") == 0)
	    state = request.getParameter("state_other");

	String city = request.getParameter("city");
	if (city.length() == 0)
	    missing.add("City");

	String street = request.getParameter("street1");
	if (street.length() == 0)
	    missing.add("Street");
	else if (request.getParameter("street2").length() > 0)
	    street = street + "\n" + request.getParameter("street2");

	String pwd = request.getParameter("password");
	if (pwd.length() == 0)
	    missing.add("Password");

	String vpwd = request.getParameter("vpassword");
	if (vpwd.length() == 0)
	    missing.add("Password Varification");

	String degType = request.getParameter("degType");
	if (degType.compareTo("other") == 0) {
	    degType = request.getParameter("degType_other");
	    if (degType.length() == 0)
		missing.add("Degree");
	}

	String major = request.getParameter("major");
	if (major.length() == 0)
	    missing.add("Major");

	String gradDate = request.getParameter("gradDate_Sem");
	if (gradDate.length() == 0)
	    missing.add("Graduation Date: Semester");
	if (request.getParameter("gradDate_Year").length() == 0)
	    missing.add("Graduation Date: Year");
	else
	    gradDate = gradDate + " " + request.getParameter("gradDate_Year");


	// Print error messages for missing entries
	if ((msize = missing.size()) > 0) {
	    for (int i = 0; i < msize; i++) {
		out.println((String) missing.get(i) + " is missing.<P>");
	    } 

	    out.println("\nPlease press the BACK botton on your " +
			"browser to enter missing/invalid entries.");	    
	    return;
	}

	// Varify existing user (last name, first name, e-mail
	try {
	    sql.append("SELECT lastName, firstName FROM member");
	    stmt = dbConn.createStatement();
	    rs = stmt.executeQuery(sql.toString());
	    while (rs.next()) {
	        if (rs.getString(1).compareToIgnoreCase(lastName) == 0 &&
		    rs.getString(2).compareToIgnoreCase(firstName) == 0) {
		    out.println("Member " + firstName + lastName + 
				" has already registered.");
		    out.println("<P>\nPlease contact the UNT Alumni by " +
				"sending e-mail to " +
				"<A HREF=\"mailto:UNTAlumni@unt.edu\">" +
				"UNTAlumni@unt.edu</A>.");
		    return;
	        }
	    }

	    sql.delete(0, sql.length());
	    sql.append("SELECT email FROM contact");
	    rs = stmt.executeQuery(sql.toString());
	    while (rs.next()) {
	        if (rs.getString(1).compareToIgnoreCase(email) == 0) {
		    out.println("E-mail has already been used.");
		    out.println("Please press the BACK botton on your " +
				"browser to enter your e-mail address again.");
		    out.println("<P>If you have enter a correct e-mail " +
				" address, you might have already " +
				"registered, so please contact the UNT " +
				"Alumni by sending e-mail to " +
				"<A HREF=\"mailto:UNTAlumni@unt.edu\">" +
				"UNTAlumni@unt.edu</A>.");
		    return;
		}
	    }
	} catch (SQLException e) {
	    response.sendError(response.SC_ACCEPTED, "The request has been " +
			       "accepted, but it failed to complete due to " +
			       "an error querying the database.");
	    out.println(e);
	    return;
	}

	// Print error message for invalid State entry
	if (err) {
	    out.println("Invalid State found.");		
	    return;
	}

	// Varify password
	if (pwd.compareTo(vpwd) != 0) {
	    out.println("Password verification failed.");
	    out.println("<P>\nPlease press the BACK botton on your browser " +
			"to re-enter your password.");
	    return;
	}


	// Create sql statements
	member.append("INSERT INTO member VALUES(\"" + lastName + "\",\"" +
		      firstName + "\",\"" + dob + "\",\"" + degType +
		      "\",\"" + major + "\",\"" + gradDate + "\",\"" + pwd +
		      "\",\"" + email + "\")");

	contact.append("INSERT INTO contact VALUES(\"" + email + "\",\"" +
		       phone + "\",\"" + street + "\",\"" + city + "\",\"" +
		       state + "\",\"" + zip + "\",\"" + country +"\")");

	has.append("INSERT INTO has VALUES(\"" + email + "\")");

	// Excute update and query
	try {
	    stmt.executeUpdate(member.toString());
       	    stmt.executeUpdate(contact.toString());
	    stmt.executeUpdate(has.toString());
	} catch (SQLException e) {
	    response.sendError(response.SC_ACCEPTED, "The request has been " +
			       "accepted, but it failed to complete due to " +
			       "an error updating the database.");
	    out.println(e);
	    return;
	}

	// Have to put a registration confirmation page
	out.println("You have successfully registered to the UNT Alumni.");

	// For testing purpose, get data from member
	try {
	    sql.delete(0, sql.length());
	    sql.append("SELECT * FROM member");
	    rs = stmt.executeQuery(sql.toString());
	}
	catch (SQLException e) {
	    response.sendError(response.SC_ACCEPTED, "The request has been " +
			       "accepted, but it failed to complete due to " +
			       "an error querying the database.");
	    out.println(e);
	    return;
	}

	// Create HTML page
	out.println("<HTML>\n\n" +
		    "<HEAD>\n" +
		    "  <TITLE>UNT Alumni</TITLE>\n" +
		    "</HEAD>\n\n" +
		    "<BODY>\n");

	// Create Table for member info
	out.println("<TABLE WIDTH=\"100%\" BORDER=\"1\">\n" +
		    "<TR>\n" +
		    "  <TD>Name</TD>\n" +
		    "  <TD>Date of Birth</TD>\n" +
		    "  <TD>Degree</TD>\n" +
		    "  <TD>Major</TD>\n" +
		    "  <TD>Graduation Date</TD>\n" +
		    "  <TD>Password</TD>\n" +
		    "  <TD>E-mail Address</TD>\n" +
		    "</TR>\n");

	// Print member info
	try {
	    while(rs.next()) {
		out.println("<TR>\n" +
			    "  <TD>" + rs.getString(2) + " " +
			    rs.getString(1) + "</TD>\n" +
			    "  <TD>" + rs.getString(3) + "</TD>\n" +
			    "  <TD>" + rs.getString(4) + "</TD>\n" +
			    "  <TD>" + rs.getString(5) + "</TD>\n" +
			    "  <TD>" + rs.getString(6) + "</TD>\n" +
			    "  <TD>" + rs.getString(7) + "</TD>\n" +
			    "  <TD>" + rs.getString(8) + "</TD>\n" +
			    "</TR>\n");
	    }

	    out.println("</TABLE>\n");
	} catch(SQLException e) {
	    System.out.println(e);
	}

	// Get data from contact
	try {
	    sql.delete(0, sql.length());
	    sql.append("SELECT * FROM contact");
	    rs = stmt.executeQuery(sql.toString());
	}
	catch (SQLException e) {
	    response.sendError(response.SC_ACCEPTED, "The request has been " +
			       "accepted, but it failed to complete due to " +
			       "an error querying the database.");
	    out.println(e);
	    return;
	}

	// Create Table for contact info
	out.println("<BR><BR><BR><BR>");
	out.println("<TABLE WIDTH=\"100%\" BORDER=\"1\">\n" +
		    "<TR>\n" +
		    "  <TD>E-mail Address</TD>\n" +
		    "  <TD>Telephone</TD>\n" +
		    "  <TD>Street</TD>\n" +
		    "  <TD>City</TD>\n" +
		    "  <TD>State, Zip Code</TD>\n" +
		    "  <TD>Country</TD>\n" +
		    "</TR>\n");

	// Print contact info
	try {
	    while(rs.next()) {
		out.println("<TR>\n" +
			    "  <TD>" + rs.getString(1) + "</TD>\n" +
			    "  <TD>" + rs.getString(2) + "</TD>\n" +
			    "  <TD>" + rs.getString(3) + "</TD>\n" +
			    "  <TD>" + rs.getString(4) + "</TD>\n" +
			    "  <TD>" + rs.getString(5) + " " +
			    rs.getString(6) + "</TD>\n" +
			    "  <TD>" + rs.getString(7) + "</TD>\n" +
			    "</TR>\n");
	    }

	    out.println("</TABLE>\n");
	} catch(SQLException e) {
	    System.out.println(e);
	}

	out.println("</BODY>\n" +
		    "</HTML>");
    } // end doPost


    public void destroy() {
	try {
	    dbConn.close();
	} catch (Exception e) {
	    System.out.println("Database close failed.");
	    System.out.println(e);
	}
    }
}





