import java.sql.*;
import java.io.*;
import java.util.*;
import javax.servlet.*;
import javax.servlet.http.*;

public class Order extends HttpServlet
{
 private ConnectionPool connPool;
 private int MAXSIZE=512;


 protected int initialConnection()
 {
  return(10);
 }

 protected int maxConnections()
 {
  return(50);
 }

 public void init() throws ServletException
 {
  String driver="org.gjt.mm.mysql.Driver";
  String url="jdbc:mysql://richese.csci.unt.edu/chung";
  String user="chung";
  String pwd="chung";
  try
  {
   connPool=new ConnectionPool(driver,url,user,pwd,
                               initialConnection(),
                               maxConnections(),
                               true);
  }
  catch(SQLException sqle)
  {
   System.err.println("Error making pool:"+sqle);
   getServletContext().log("Error making pool:"+sqle);
   connPool = null;
  }
 }

 public void destroy()
 {
  connPool.closeAllConnections();
 }

 public void doGet(HttpServletRequest request,
                   HttpServletResponse response)
                   throws ServletException, IOException
 {
  doPost(request,response);
 }

 public void doPost(HttpServletRequest request,
                    HttpServletResponse response)
                    throws ServletException, IOException
 {
  PrintWriter out = response.getWriter();

  HttpSession session = request.getSession(true);
  String userSession = (String)session.getValue("user_session");

  int errorFlag = 0;

  Inventory inventory = new Inventory();

  response.setContentType("text/html");

  String tempOpt = request.getParameter("option");
  String emailAddr = request.getParameter("email");
  String year = request.getParameter("year");
  String month= request.getParameter("month");
  String day  = request.getParameter("day");

  if((day.length()==0)||(month.length()==0)||(year.length()==0))
  {
    out.println("<p>You must enter all the field required" +
                " starts with year, month, and day. Press "+
                " BACK botton on the browser to go back to"+
                " the previous page.</p>");
    return;
  }

  try
  {
    boolean error=false;

    int preYear = (new Integer(year)).intValue();
    int preMonth = (new Integer(month)).intValue();
    int preDay  = (new Integer(day)).intValue();

    if(preYear<2001)
    { error=true;
      out.println("<p>You must enter the current year (2001)</p>");
    }
    if((preMonth>12) || (preMonth<1))
    { error=true;
      out.println("<p>You must enter the month between 1 and 12</p>");
    }
    if((preDay<1) || (preDay>31))
    { error=true;
      out.println("<p>You must enter the day in range of 1-31</p>");
    }
    if((preMonth==2)&&(preDay>28)) //ignore the leap year
    { error=true;
      out.println("<p>You enter invalid range of day for Febuary</p>");
    }
    if(error == true)
    {
      out.println("<p>Press BACK button on the browser to go back to "+
                  "the previous page</p>");
      return;
    }

 // if(preDay<10)
 //   day = "0"+day;

  String date = year + "-" + month + "-" + day;

  int option = (new Integer(tempOpt)).intValue();
  //option = 1 --> workstation order
  //option = 2 --> laptop order
  //option = 3 --> computer parts order

   switch(option)
   {
    case 1: processWorkstation(inventory,emailAddr,
                               date,out,userSession,request,response);
            break;
    case 2: processLaptop(inventory,emailAddr,
                          date,out,userSession,request,response);
            break;
    case 3: processParts(inventory,emailAddr,date,out,
                         userSession,request,response);
   }

  }
  catch(NumberFormatException nfe)
  {
    out.println("<BR>" + nfe + "</br>");
    return;
  }
  catch(IOException ioex)
  {
    out.println(ioex);
    return;
  }

 }//end doPost's method

/**
 * getModel's method is to get model of the Item given the
 * String type.
 * @param  Vector vec contains user's order
 *         String type contains type of Item
 * @return null if not found otherwise the result of search
 */
 public String getModel(Vector vec, String type)
 {
  int size=vec.size();
  int not=-1;
  String tempString;

  Item tempItem;

  for(int i=0;i<size;i++)
  {
   tempItem = (Item)vec.elementAt(i);
   tempString = tempItem.getType();
   if(tempString.indexOf(type)!=not)
     return tempString;
  }
  return null;
 }

/**
 * getPrice's method is to get price of the Item given
 * the String type of the Item.
 * @param  Vector vec contains user's order
 *         String type contains the type of Item
 * @return 0 if not found otherwise return the result
 */
 public float getPrice(Vector vec, String type)
 {
  int size=vec.size();
  int not=-1;
  String tempString;
  Item tempItem;

  for(int i=0;i<size;i++)
  {
    tempItem = (Item)vec.elementAt(i);
    tempString = tempItem.getType();
    if(tempString.indexOf(type)!=not)
      return tempItem.getPrice();
  }
  return 0;
 }

/**
 * getQty's method is to get the quantity of the
 * purchase Item.
 * @param  Vector vec contains user's order
 *         String type contains the type of Item
 * @return 0 if not found otherwise return result
 */
 public int getQty(Vector vec, String type)
 {
  int size=vec.size();
  int not=-1;
  String tempString;
  Item tempItem;

  for(int i=0;i<size;i++)
  {
    tempItem = (Item)vec.elementAt(i);
    tempString = tempItem.getType();
    if(tempString.indexOf(type)!=not)
      return tempItem.getQuantity();
  }
  return 0;
 }


/**
 * processWorkstation's method is to get parameters from
 * the order_form1.jsp. Retrieve and verify the values
 * then call fillDB's method to fill order into the database
 * @param  Inventory inventory contains the items and description
 *         String cpu contains the cpu type
 *         String emailAddr contains user email address
 *         String date contains date of order
 *         PrintWriter out contains response to write
 *         Connection connection contains connection to database
 *         HttpServletRequest request contains user requests
 *         HttpServletResponse response contains responses for requests
 * @return int errorFlag = 0 if no error otherwise errorFlag = 1
 */
 public void processWorkstation(Inventory inventory,
                                String emailAddr,
				String date,
                                PrintWriter out,
                                String userSession,
				HttpServletRequest request,
                                HttpServletResponse response)
                                throws IOException
 {
  NumberGenerator ng = new NumberGenerator();
  int track = ng.generateInt();
  String cpu = request.getParameter("cpu");

  int quantity_cpu=
  (new Integer(request.getParameter("workstation")).intValue());

  if((quantity_cpu <1)||(quantity_cpu<0))
  {
    out.println("<BR><B><font color=red>"+
                "You must specify how many workstation you want"+
                " to order. Press BACK button to return to the "+
                "previous page. </font></b></br>");
    return;
  }

  int flag = 1; //indicating it is workstation order

  Vector tempVec = getAllValues(request,response,out,flag,inventory);

  if(tempVec.size()==0)
    return;

  StringBuffer parts = new StringBuffer(MAXSIZE);
  StringBuffer workst= new StringBuffer(MAXSIZE);
  StringBuffer order = new StringBuffer(MAXSIZE);
  StringBuffer mytrack = new StringBuffer(MAXSIZE);

  String status ="In Progress";

  String hdd_model = getModel(tempVec,"hd");
  String fdd_model = getModel(tempVec,"fd");
  String ram_model = getModel(tempVec,"mem");
  String nic_model = getModel(tempVec,"nic");
  String mouse_model = getModel(tempVec,"mouse");
  String keyboard_model = getModel(tempVec,"keyboard");
  String videocard_model= getModel(tempVec,"vidcard");
  String soundcard_model= getModel(tempVec,"sndcard");
  String cdrom_model = getModel(tempVec,"cdrom");
  String cdrw_model = getModel(tempVec,"cdrw");
  String dvd_model = getModel(tempVec,"dvdrom");
  String zip_model = getModel(tempVec,"zip");
  String speaker_model = getModel(tempVec,"speaker");
  String os_model = getModel(tempVec,"os");
  String monitor_model = getModel(tempVec,"mon")+getModel(tempVec,"lcd");

  int hdd_qty = getQty(tempVec,"hd");
  int fdd_qty = getQty(tempVec,"fd");
  int ram_qty = getQty(tempVec,"mem");
  int nic_qty= getQty(tempVec,"nic");
  int mouse_qty= getQty(tempVec,"mouse");
  int keyboard_qty= getQty(tempVec,"keyboard");
  int videocard_qty= getQty(tempVec,"vidcard");
  int soundcard_qty = getQty(tempVec,"sndcard");
  int cdrom_qty= getQty(tempVec,"cdrom");
  int cdrw_qty= getQty(tempVec,"cdrw");
  int dvd_qty= getQty(tempVec,"dvdrom");
  int zip_qty= getQty(tempVec,"zip");
  int speaker_qty= getQty(tempVec,"speaker");
  int os_qty= getQty(tempVec,"os");
  int monitor_qty = getQty(tempVec,"mon")+getQty(tempVec,"lcd");
  float hdd_price = getPrice(tempVec,"hd");
  float fdd_price= getPrice(tempVec,"fd");
  float ram_price= getPrice(tempVec,"mem");
  float nic_price= getPrice(tempVec,"nic");
  float mouse_price= getPrice(tempVec,"mouse");
  float keyboard_price= getPrice(tempVec,"keyboard");
  float videocard_price= getPrice(tempVec,"vidcard");
  float soundcard_price= getPrice(tempVec,"sndcard");
  float cdrom_price= getPrice(tempVec,"cdrom");
  float dvdrom_price= getPrice(tempVec,"dvdrom");
  float cdrw_price= getPrice(tempVec,"cdrw");
  float os_price= getPrice(tempVec,"os");
  float monitor_price= (getPrice(tempVec,"mon")+getPrice(tempVec,"lcd"));
  float zip_price= getPrice(tempVec,"zip");
  float speaker_price= getPrice(tempVec,"speaker");

  float total=hdd_price+fdd_price+ram_price+nic_price+mouse_price+
        keyboard_price+videocard_price+soundcard_price+cdrom_price+
        dvdrom_price+cdrw_price+os_price+monitor_price+zip_price+
        speaker_price;

  int not = -1;
  if(cpu.indexOf("800Mhz")!=not)
     total+=(349.00 * (float)quantity_cpu);
  if(cpu.indexOf("700Mhz")!=not)
     total+=(2590.00 * (float)quantity_cpu);
  if(cpu.indexOf("1Ghz")!=not)
     total+=(615.00 * (float)quantity_cpu);

  parts.append("INSERT INTO myequipment VALUES(\""+ track +"\","+
               "\""+hdd_model+"\",\""+hdd_qty+"\","+
               "\""+fdd_model+"\",\""+fdd_qty+"\","+
               "\""+ram_model+"\",\""+ram_qty+"\","+
               "\""+nic_model+"\",\""+nic_qty+"\","+
               "\""+mouse_model+"\",\""+mouse_qty+"\","+
               "\""+keyboard_model+"\",\""+keyboard_qty+"\","+
               "\""+videocard_model+"\",\""+videocard_qty+"\","+
               "\""+soundcard_model+"\",\""+soundcard_qty+"\","+
               "\""+cdrom_model+"\",\""+cdrom_qty+"\","+
               "\""+cdrw_model+"\",\""+cdrw_qty+"\","+
               "\""+dvd_model+"\",\""+dvd_qty+"\","+
               "\""+zip_model+"\",\""+zip_qty+"\","+
               "\""+speaker_model+"\",\""+speaker_qty+"\","+
               "\""+os_model+"\",\""+os_qty+"\","+
               "\""+monitor_qty+"\",\""+monitor_qty+"\")");

  workst.append("INSERT INTO myworkstation VALUES(\""+track+"\","+
                "\""+cpu+"\",\""+quantity_cpu+"\")");

  order.append("INSERT INTO myorder VALUES(\""+emailAddr+"\","+
               "\""+track+"\",\""+ status +"\","+
               "\""+date+"\","+total+")");

  mytrack.append("INSERT INTO myequipt VALUES(\""+track+"\")");

  try
  {
   Connection connection = connPool.getConnection();
   fillDB(connection,
          parts.toString(),
          null,
          workst.toString(),
          order.toString(),
          mytrack.toString(),
          response,
          flag);

   display(tempVec,
           inventory,
           cpu,
           flag,
           quantity_cpu,
           total,
           track,
           userSession,
           emailAddr,
           date,
           out,
           response);
  }
  catch(SQLException sqle)
  {
   response.sendError(response.SC_ACCEPTED, "The request has been " +
                     "accepted, but it failed to complete due to " +
 	             "an error updating the database.");
   out.println(sqle);
   return;
  }
  catch(IOException ioex)
  {
   out.println(ioex);
   return;
  }

 } // end of processWorkstation's method

/**
 * processLaptop's method is to get parameters from the order_form2.jsp
 * It retrieves and verifies the order for laptop and then call
 * fillDB's method to fill up the database with the order.
 * @param  Inventory inventory contains the items and description
 *         String emailAddr contains user email address
 *         String date contains date of order
 *         PrintWriter out contains response to write
 *         Connection connection contains connection to database
 *         HttpServletRequest contains user requests
 *         HttpServletResponse response contains responses for requests
 * @return int errorFlag = 0 if no error otherwise errorFlag = 1
 */
 public void processLaptop(Inventory inventory,
			   String emailAddr,
			   String date,
                           PrintWriter out,
			   String userSession,
			   HttpServletRequest request,
                           HttpServletResponse response)
 throws IOException
 {

  int flag = 2; //indicating it is laptop order

  Vector tempVec = getAllValues(request,response,out,flag,inventory);

  if(tempVec.size()==0)
    return;

  NumberGenerator ng = new NumberGenerator();
  int track = ng.generateInt();

  StringBuffer laptop = new StringBuffer(MAXSIZE);
  StringBuffer order  = new StringBuffer(MAXSIZE);
  StringBuffer mytrack  = new StringBuffer(MAXSIZE);
  String status ="in progress";

  String laptop_model = getModel(tempVec,"laptop");
  float laptop_price = getPrice(tempVec,"laptop");
  int laptop_qty = getQty(tempVec,"laptop");

  float total = laptop_price;

  laptop.append("INSERT INTO mylaptop VALUES(\""+track+"\","+
                "\""+laptop_model+"\",\""+laptop_qty+"\")");

  order.append("INSERT INTO myorder VALUES(\""+emailAddr+"\","+
               "\""+track+"\",\""+ status +"\",\""+
                date+"\","+total+")");

  mytrack.append("INSERT INTO myequipt VALUES(\""+track+"\")");

  try
  {
   Connection connection = connPool.getConnection();
   fillDB(connection, 
          null, 
          laptop.toString(), 
          null, 
          order.toString(),
          mytrack.toString(),
          response,
          flag);


   display(tempVec,
           inventory,
           null,
           flag,
           0,
           total,
           track,
           userSession,
           emailAddr,
           date,
           out,
           response);
  }
  catch(SQLException sqle) 
  {
   response.sendError(response.SC_ACCEPTED, "The request has been " +
                      "accepted, but it failed to complete due to " +
 	              "an error updating the database.");
   out.println(sqle);
   return; 
  }
  catch(IOException ioex)
  {
   out.println(ioex);
   return;
  }
 } // end of processLaptop's method

/**
 * processParts's method is to get parameters from the order_form3.jsp
 * It retreives and verifies the order from computer parts then
 * it calls fillDB's method to fill up the database with the order.
 * @param  Inventory inventory contains the items and description
 *         String emailAddr contains the user email address
 *         String date contains date of order
 *         Connection connection contains connection to database
 *         HttpServletRequest request contains user requests
 *         HttpServletResponse response contains responses for requests
 * @return int errorFlag = 0 if no error otherwise errorFlag = 1
 */
 public void processParts(Inventory inventory,
                          String emailAddr,
			  String date,
			  PrintWriter out,
                          String userSession,
			  HttpServletRequest request,
                          HttpServletResponse response)
 throws IOException
 {
  int flag = 3; //indicating it is computer parts order

  Vector tempVec = getAllValues(request,response,out,flag,inventory);
  if(tempVec.size() ==0)
    return;

  NumberGenerator ng = new NumberGenerator();
  int track = ng.generateInt();

  StringBuffer parts = new StringBuffer(MAXSIZE);
  StringBuffer order = new StringBuffer(MAXSIZE);
  StringBuffer mytrack = new StringBuffer(MAXSIZE);

  String status ="in progress";

  String hdd_model = getModel(tempVec,"hd");
  String fdd_model = getModel(tempVec,"fd");
  String ram_model = getModel(tempVec,"mem");
  String nic_model = getModel(tempVec,"nic");
  String mouse_model = getModel(tempVec,"mouse");
  String keyboard_model = getModel(tempVec,"keyboard");
  String videocard_model= getModel(tempVec,"vidcard");
  String soundcard_model= getModel(tempVec,"sndcard");
  String cdrom_model = getModel(tempVec,"cdrom");
  String cdrw_model = getModel(tempVec,"cdrw");
  String dvd_model = getModel(tempVec,"dvdrom");
  String zip_model = getModel(tempVec,"zip");
  String speaker_model = getModel(tempVec,"speaker");
  String os_model = getModel(tempVec,"os");
  String monitor_model = getModel(tempVec,"mon")+getModel(tempVec,"lcd");

  int hdd_qty = getQty(tempVec,"hd");
  int fdd_qty = getQty(tempVec,"fd");
  int ram_qty = getQty(tempVec,"mem");
  int nic_qty= getQty(tempVec,"nic");
  int mouse_qty= getQty(tempVec,"mouse");
  int keyboard_qty= getQty(tempVec,"keyboard");
  int videocard_qty= getQty(tempVec,"vidcard");
  int soundcard_qty = getQty(tempVec,"sndcard");
  int cdrom_qty= getQty(tempVec,"cdrom");
  int cdrw_qty= getQty(tempVec,"cdrw");
  int dvd_qty= getQty(tempVec,"dvdrom");
  int zip_qty= getQty(tempVec,"zip");
  int speaker_qty= getQty(tempVec,"speaker");
  int os_qty= getQty(tempVec,"os");
  int monitor_qty = getQty(tempVec,"mon")+getQty(tempVec,"lcd");

  float hdd_price = getPrice(tempVec, "hd");
  float fdd_price= getPrice(tempVec, "fd");
  float ram_price= getPrice(tempVec, "mem");
  float nic_price= getPrice(tempVec, "nic");
  float mouse_price= getPrice(tempVec, "mouse");
  float keyboard_price= getPrice(tempVec, "keyboard");
  float videocard_price= getPrice(tempVec, "vidcard");
  float soundcard_price= getPrice(tempVec, "sndcard");
  float cdrom_price= getPrice(tempVec, "cdrom");
  float dvdrom_price= getPrice(tempVec, "dvdrom");
  float cdrw_price= getPrice(tempVec, "cdrw");
  float os_price= getPrice(tempVec, "os");
  float monitor_price=(getPrice(tempVec, "mon")+getPrice(tempVec,"lcd"));
  float zip_price= getPrice(tempVec, "zip");
  float speaker_price= getPrice(tempVec, "speaker");

  float total=hdd_price+fdd_price+ram_price+nic_price+mouse_price+
        keyboard_price+videocard_price+soundcard_price+cdrom_price+
        dvdrom_price+cdrw_price+os_price+monitor_price+zip_price+speaker_price;

  parts.append("INSERT INTO myequipment VALUES(\""+ track +"\","+
               "\""+hdd_model+"\",\""+hdd_qty+"\","+
               "\""+fdd_model+"\",\""+fdd_qty+"\","+
               "\""+ram_model+"\",\""+ram_qty+"\","+
               "\""+nic_model+"\",\""+nic_qty+"\","+
               "\""+mouse_model+"\",\""+mouse_qty+"\","+
               "\""+keyboard_model+"\",\""+keyboard_qty+"\","+
               "\""+videocard_model+"\",\""+videocard_qty+"\","+
               "\""+soundcard_model+"\",\""+soundcard_qty+"\","+
               "\""+cdrom_model+"\",\""+cdrom_qty+"\","+
               "\""+cdrw_model+"\",\""+cdrw_qty+"\","+
               "\""+dvd_model+"\",\""+dvd_qty+"\","+
               "\""+zip_model+"\",\""+zip_qty+"\","+
               "\""+speaker_model+"\",\""+speaker_qty+"\","+
               "\""+os_model+"\",\""+os_qty+"\","+
               "\""+monitor_qty+"\",\""+monitor_qty+"\")");

  order.append("INSERT INTO myorder VALUES(\""+emailAddr+"\","+
               "\""+track+"\",\""+ status +"\",\""+
               date+"\","+total+")");

  mytrack.append("INSERT INTO myequipt VALUES(\""+track+"\")");

  try
  {
   Connection connection = connPool.getConnection();
   fillDB(connection,
          parts.toString(),
          null,
          null,
          order.toString(),
          mytrack.toString(),
          response,
          flag);

   display(tempVec,
           inventory,
           null,
           flag,
           0,   
           total,
           track,
           userSession,
           emailAddr,
           date,
           out,
           response);
  }
  catch(SQLException sqle) 
  {
   response.sendError(response.SC_ACCEPTED, "The request has been " +
                      "accepted, but it failed to complete due to " +
 	              "an error updating the database.");
   out.println(sqle);
   return;
  }
  catch(IOException ioex)
  {
   out.println(ioex);
  }
 } // end of processParts's method

/**
 * display's method is to display the confirmation page for the user
 * order. tempVec contains all the information to be display by this
 * method. Inventory contains the default price of each item orders.
 * While the int flag contains a flag to tell what order is it.
 * flag 1 = workstation, flag 2 = laptop, and flag 3 = computer parts.
 * @param  Vector tempVec contains all the information to be display
 *         Inventory inventory contains the default information/reference
 *         int flag contains flag to tell which order is it.
 *         PrintWriter out contains connection to write response
 *         HttpServletResponse contains response to the user request.
 */
 public void display(Vector tempVec,
                     Inventory inventory,
                     String cpu,
                     int flag,
                     int quantity_cpu,
                     float total,
                     int trackNumber,
                     String userSession,
                     String emailAddr,
                     String date,
                     PrintWriter out,
                     HttpServletResponse response)
 {
  int not=-1;
  int count=1;
  int size=tempVec.size();
  String order = null;
  String cpuDescp = null;
  float cpuPrice = 0;
  Item myItem;

  if(flag == 1)
  {
    order = new String("Workstation Order of "+cpu);
    cpuDescp = new String("CPU: "+cpu+" (include case & motherboard)");
    if(cpu.indexOf("700Mhz")!=not)
      cpuPrice = (new Float(2590.00)).floatValue();
    else if(cpu.indexOf("800Mhz")!=not)
      cpuPrice = (new Float(349.00)).floatValue();
    else if(cpu.indexOf("1Ghz")!=not)
      cpuPrice = (new Float(615.00)).floatValue(); 
  }
  else if(flag == 2)
    order = new String("Laptop Order");
  else if(flag == 3)
    order = new String("Computer Parts Order");

  out.println("<html><head><title>Confirmation Order for"+userSession+
              "</title></head>"+
              "<body bgcolor=ivory link=blue alink=green vlink=magneta>");
  out.println("<BR></BR>\n");
  out.println("<font face=arial size=+2><b>\n");
  out.println("Confirmation "+order+" for: " + userSession);
  out.println("</font></b><br></br>");
  out.println("Your tracking number is:<b><font color=red>"+ trackNumber+
              "</font></b><br>Your login/email address is : "+emailAddr+
              " </br>");
  out.println("<table border=1 cellspacing=2 cellpadding=2 width=\"75%\">");
  out.println("<tr>");
  out.println("<td colspan=5 align=center><font face=arial size=+1><b>");
  out.println("On "+date+" you order the following items:</b></font></td>\n");
  out.println("</tr>");
  out.println("<tr>");
  out.println("<td><b>No.</b></td>");
  out.println("<td><b>Type and Description of Items</b></td>");
  out.println("<td><b>Price/Unit</b></td>");
  out.println("<td><b>Qty</b></td>");
  out.println("<td><b>Subtotal</b></td>");
  out.println("</tr>\n");
  if(flag == 1)
  { 
   out.println("<tr>");
   out.println("<td>" + count + "</td>");
   out.println("<td>" + cpuDescp +"</td>");
   out.println("<td>" + cpuPrice +"</td>");
   out.println("<td>" + quantity_cpu+"</td>");
   out.println("<td>" + (cpuPrice * (float)quantity_cpu)+"</td>");
   out.println("</tr>");
   count+=1;
  }
  for(int i=0;i<size;i++)
  {
   myItem = (Item)tempVec.elementAt(i);
   out.println("<tr>");
   out.println("<td>"+count+"</td>");
   out.println("<td>"+
   inventory.getItemDesc(myItem.getType())+"</td>");
   out.println("<td>US$"+
   inventory.getItemPrice(inventory.getInventory(myItem.getType()))+"</td>");
   out.println("<td>"+ myItem.getQuantity() +"</td>");
   out.println("<td>US$"+ myItem.getPrice() +"</td>");
   out.println("</tr>");
   count+=1;
  }
  out.println("<tr><td></td><td></td><td></td><td>"+
              "<b><i>Total amount due is:</i></b></td>" +
              "<td>US$" + total + "</td></tr>");
  out.println("</table><br></br><br></br>\n");
  out.println("|&nbsp;<a href=http://jsp.csci.unt.edu/chung/index.html#Order>"+
              " Home</a>&nbsp;|&nbsp;"+
              "<a href=http://jsp.csci.unt.edu/chung/begin_order_form.jsp>"+"Begin Order</a>&nbsp;|&nbsp;"+
              "<a href=http://jsp.csci.unt.edu/chung/jsp/cancel_order.jsp"+
              "?email="+emailAddr+">"+
              "Cancel Order</a>&nbsp;|&nbsp;"+
              "<a href=http://jsp.csci.unt.edu/chung/jsp/track_order.jsp"+
              "?email="+emailAddr+">"+
              "Track your order</a> &nbsp;|&nbsp;"+
              "<a href=http://jsp.csci.unt.edu/chung/jsp/change_order.jsp"+
              "?email="+emailAddr+">"+
              "Change your order </a>&nbsp;|");
  out.println("</body></html>");
 } // end display's method

/**
 * getAllValues' method is to get all the value of from the field
 * that users input in the order_form#.jsp. After getting all the
 * values from the jsp, it stores into the vector and return it.
 * @param  HttpServletRequest request contains users requests
 *         int flag contains 1 & 3 for order_form1.jsp & order_form3.jsp
 *                           2 for order_form2.jsp
 * @return Vector contains all the user inputs.
 */
 public Vector getAllValues(HttpServletRequest request,
			    HttpServletResponse response,
			    PrintWriter out,
                            int flag,
                            Inventory inventory)
 {
   Vector tempVector = new Vector();
   try
   {
    if(flag == 2)
    {
     String laptop1 = request.getParameter("laptop1");
     String laptop2 = request.getParameter("laptop2");
     String laptop3 = request.getParameter("laptop3");
     String laptop4 = request.getParameter("laptop4");
     if(laptop1.length()>0)
     {
      Item temp1 = new Item();
      int qty = (new Integer(laptop1)).intValue();
      float basePrice =
      inventory.getItemPrice(inventory.getInventory("laptop1"));
      temp1.setPrice(basePrice*(float)qty);
      temp1.setQuantity(qty);
      temp1.setType("laptop1");
      temp1.setDescription(inventory.getItemDesc("laptop1"));
      tempVector.addElement((Object)temp1);
     }
     if(laptop2.length()>0)
     {

      Item temp2 = new Item();
      int qty = (new Integer(laptop2)).intValue();
      float basePrice =
      inventory.getItemPrice(inventory.getInventory("laptop2"));
      temp2.setPrice(basePrice*(float)qty);
      temp2.setType("laptop2");
      temp2.setDescription(inventory.getItemDesc("laptop2"));
      tempVector.addElement((Object)temp2);
     }
     if(laptop3.length()>0)
     {
      Item temp3 = new Item();
      int qty = (new Integer(laptop3)).intValue();
      float basePrice =
      inventory.getItemPrice(inventory.getInventory("laptop3"));
      temp3.setPrice(basePrice*(float)qty);
      temp3.setType("laptop3");
      temp3.setDescription(inventory.getItemDesc("laptop3"));
      tempVector.addElement((Object)temp3);
     }
     if(laptop4.length()>0)
     {
      Item temp4 = new Item();
      int qty = (new Integer(laptop4)).intValue();
      float basePrice =
      inventory.getItemPrice(inventory.getInventory("laptop4"));
      temp4.setPrice(basePrice*(float)qty);
      temp4.setType("laptop4");
      temp4.setDescription(inventory.getItemDesc("laptop4"));
      tempVector.addElement((Object)temp4);
     }

    }
    else
    {
     String hd1 = request.getParameter("hd1");
     String hd2 = request.getParameter("hd2");
     String fd1 = request.getParameter("fd1");
     String mem1 = request.getParameter("mem1");
     String mem2 = request.getParameter("mem2");
     String vidcard1 = request.getParameter("vidcard1");
     String vidcard2 = request.getParameter("vidcard2");
     String keyboard1 = request.getParameter("keyboard1");
     String keyboard2 = request.getParameter("keyboard2");
     String mouse1 = request.getParameter("mouse1");
     String mouse2 = request.getParameter("mouse2");
     String sndcard1 = request.getParameter("sndcard1");
     String sndcard2 = request.getParameter("sndcard2");
     String mon1 = request.getParameter("mon1");
     String mon2 = request.getParameter("mon2");
     String mon3 = request.getParameter("mon3");
     String lcd1 = request.getParameter("lcd1");
     String lcd2 = request.getParameter("lcd2");
     String cdrom1 = request.getParameter("cdrom1");
     String cdrw1 = request.getParameter("cdrw1");
     String dvdrom1 = request.getParameter("dvdrom1");
     String zip1 = request.getParameter("zip1");
     String nic2 = request.getParameter("nic2");
     String nic1 = request.getParameter("nic1");
     String os1 = request.getParameter("os1");
     String os2 = request.getParameter("os2");
     String speaker1 = request.getParameter("speaker1");
     String speaker2 = request.getParameter("speaker2");

     if(hd1.length()>0)
     {
      Item temp1 = new Item();
      int qty = (new Integer(hd1)).intValue();
      float basePrice =
      inventory.getItemPrice(inventory.getInventory("hd1"));
      temp1.setPrice(basePrice*(float)qty);
      temp1.setQuantity(qty);
      temp1.setType("hd1");
      temp1.setDescription(inventory.getItemDesc("hd1"));
      tempVector.addElement((Object)temp1);
     }
     if(hd2.length()>0)
     {
      Item temp2 = new Item();
      int qty = (new Integer(hd2)).intValue();
      float basePrice =
      inventory.getItemPrice(inventory.getInventory("hd2"));
      temp2.setPrice(basePrice*(float)qty);
      temp2.setQuantity(qty);
      temp2.setType("hd2");
      temp2.setDescription(inventory.getItemDesc("hd2"));
      tempVector.addElement((Object)temp2);
     }
     if(mem1.length()>0)
     {
      Item temp3 = new Item();
      int qty = (new Integer(mem1)).intValue();
      float basePrice =
      inventory.getItemPrice(inventory.getInventory("mem1"));
      temp3.setPrice(basePrice*(float)qty);
      temp3.setQuantity(qty);
      temp3.setType("mem1");
      temp3.setDescription(inventory.getItemDesc("mem1"));
      tempVector.addElement((Object)temp3);
     }
     if(mem2.length()>0)
     {
      Item temp4 = new Item();
      int qty = (new Integer(mem2)).intValue();
      float basePrice =
      inventory.getItemPrice(inventory.getInventory("mem2"));
      temp4.setPrice(basePrice*(float)qty);
      temp4.setQuantity(qty);
      temp4.setType("mem2");
      temp4.setDescription(inventory.getItemDesc("mem2"));
      tempVector.addElement((Object)temp4);
     }
     if(vidcard1.length()>0)
     {
      Item temp5 = new Item();
      int qty = (new Integer(vidcard1)).intValue();
      float basePrice =
      inventory.getItemPrice(inventory.getInventory("vidcard1"));
      temp5.setPrice(basePrice*(float)qty);
      temp5.setQuantity(qty);
      temp5.setType("vidcard1");
      temp5.setDescription(inventory.getItemDesc("vidcard1"));
      tempVector.addElement((Object)temp5);
     }
     if(vidcard2.length()>0)
     {
      Item temp6 = new Item();
      int qty = (new Integer(vidcard2)).intValue();
      float basePrice =
      inventory.getItemPrice(inventory.getInventory("vidcard2"));
      temp6.setPrice(basePrice*(float)qty);
      temp6.setQuantity(qty);
      temp6.setType("vidcard2");
      temp6.setDescription(inventory.getItemDesc("vidcard2"));
      tempVector.addElement((Object)temp6);
     }
     if(keyboard1.length()>0)
     {
      Item temp7 = new Item();
      int qty = (new Integer(keyboard1)).intValue();
      float basePrice =
      inventory.getItemPrice(inventory.getInventory("keyboard1"));
      temp7.setPrice(basePrice*(float)qty);
      temp7.setQuantity(qty);
      temp7.setType("keyboard1");
      temp7.setDescription(inventory.getItemDesc("keyboard1"));
      tempVector.addElement((Object)temp7);
     }
     if(keyboard2.length()>0)
     {
      Item temp8 = new Item();
      int qty = (new Integer(keyboard2)).intValue();
      float basePrice =
      inventory.getItemPrice(inventory.getInventory("keyboard2"));
      temp8.setPrice(basePrice*(float)qty);
      temp8.setQuantity(qty);
      temp8.setType("keyboard2");
      temp8.setDescription(inventory.getItemDesc("keyboard2"));
      tempVector.addElement((Object)temp8);
     }
     if(mouse1.length()>0)
     {
      Item temp9 = new Item();
      int qty = (new Integer(mouse1)).intValue();
      float basePrice =
      inventory.getItemPrice(inventory.getInventory("mouse1"));
      temp9.setPrice(basePrice*(float)qty);
      temp9.setQuantity(qty);
      temp9.setType("mouse1");
      temp9.setDescription(inventory.getItemDesc("mouse1"));
      tempVector.addElement((Object)temp9);
     }
     if(mouse2.length()>0)
     {
      Item temp10 = new Item();
      int qty = (new Integer(mouse2)).intValue();
      float basePrice =
      inventory.getItemPrice(inventory.getInventory("mouse2"));
      temp10.setPrice(basePrice*(float)qty);
      temp10.setQuantity(qty);
      temp10.setType("mouse2");
      temp10.setDescription(inventory.getItemDesc("mouse2"));
      tempVector.addElement((Object)temp10);
     }
     if(sndcard1.length()>0)
     {
      Item temp11 = new Item();
      int qty = (new Integer(sndcard1)).intValue();
      float basePrice =
      inventory.getItemPrice(inventory.getInventory("sndcard1"));
      temp11.setPrice(basePrice*(float)qty);
      temp11.setQuantity(qty);
      temp11.setType("sndcard1");
      temp11.setDescription(inventory.getItemDesc("sndcard1"));
      tempVector.addElement((Object)temp11);
     }
     if(sndcard2.length()>0)
     {
      Item temp12 = new Item();
      int qty = (new Integer(sndcard2)).intValue();
      float basePrice =
      inventory.getItemPrice(inventory.getInventory("sndcard2"));
      temp12.setPrice(basePrice*(float)qty);
      temp12.setQuantity(qty);
      temp12.setType("sndcard2");
      temp12.setDescription(inventory.getItemDesc("sndcard2"));
      tempVector.addElement((Object)temp12);
     }
     if(mon1.length()>0)
     {
      Item temp13 = new Item();
      int qty = (new Integer(mon1)).intValue();
      float basePrice =
      inventory.getItemPrice(inventory.getInventory("mon1"));
      temp13.setPrice(basePrice*(float)qty);
      temp13.setQuantity(qty);
      temp13.setType("mon1");
      temp13.setDescription(inventory.getItemDesc("mon1"));
      tempVector.addElement((Object)temp13);
     }
     if(mon2.length()>0)
     {
      Item temp14 = new Item();
      int qty = (new Integer(mon2)).intValue();
      float basePrice =
      inventory.getItemPrice(inventory.getInventory("mon2"));
      temp14.setPrice(basePrice*(float)qty);
      temp14.setQuantity(qty);
      temp14.setType("mon2");
      temp14.setDescription(inventory.getItemDesc("mon2"));
      tempVector.addElement((Object)temp14);
     }
     if(mon3.length()>0)
     {
      Item temp15 = new Item();
      int qty = (new Integer(mon3)).intValue();
      float basePrice =
      inventory.getItemPrice(inventory.getInventory("mon3"));
      temp15.setPrice(basePrice*(float)qty);
      temp15.setQuantity(qty);
      temp15.setType("mon3");
      temp15.setDescription(inventory.getItemDesc("mon3"));
      tempVector.addElement((Object)temp15);
     }
     if(lcd1.length()>0)
     {
      Item temp16 = new Item();
      int qty = (new Integer(lcd1)).intValue();
      float basePrice =
      inventory.getItemPrice(inventory.getInventory("lcd1"));
      temp16.setPrice(basePrice*(float)qty);
      temp16.setQuantity(qty);
      temp16.setType("lcd1");
      temp16.setDescription(inventory.getItemDesc("lcd1"));
      tempVector.addElement((Object)temp16);
     }
     if(lcd2.length()>0)
     {
      Item temp17 = new Item();
      int qty = (new Integer(lcd2)).intValue();
      float basePrice =
      inventory.getItemPrice(inventory.getInventory("lcd2"));
      temp17.setPrice(basePrice*(float)qty);
      temp17.setQuantity(qty);
      temp17.setType("lcd2");
      temp17.setDescription(inventory.getItemDesc("lcd2"));
      tempVector.addElement((Object)temp17);
     }
     if(cdrom1.length()>0)
     {
      Item temp18 = new Item();
      int qty = (new Integer(cdrom1)).intValue();
      float basePrice =
      inventory.getItemPrice(inventory.getInventory("cdrom1"));
      temp18.setPrice(basePrice*(float)qty);
      temp18.setQuantity(qty);
      temp18.setType("cdrom1");
      temp18.setDescription(inventory.getItemDesc("cdrom1"));
      tempVector.addElement((Object)temp18);
     }
     if(cdrw1.length()>0)
     {
      Item temp19 = new Item();
      int qty = (new Integer(cdrw1)).intValue();
      float basePrice =
      inventory.getItemPrice(inventory.getInventory("cdrw1"));
      temp19.setPrice(basePrice*(float)qty);
      temp19.setQuantity(qty);
      temp19.setType("cdrw1");
      temp19.setDescription(inventory.getItemDesc("cdrw1"));
      tempVector.addElement((Object)temp19);
     }
     if(dvdrom1.length()>0)
     {
      Item temp20 = new Item();
      int qty = (new Integer(dvdrom1)).intValue();
      float basePrice =
      inventory.getItemPrice(inventory.getInventory("dvdrom1"));
      temp20.setQuantity(qty);
      temp20.setPrice(basePrice*(float)qty);
      temp20.setType("dvdrom1");
      temp20.setDescription(inventory.getItemDesc("dvdrom1"));
      tempVector.addElement((Object)temp20);
     }
     if(fd1.length()>0)
     {
      Item temp21 = new Item();
      int qty = (new Integer(fd1)).intValue();
      float basePrice =
      inventory.getItemPrice(inventory.getInventory("fd1"));
      temp21.setPrice(basePrice*(float)qty);
      temp21.setQuantity(qty);
      temp21.setType("fd1");
      temp21.setDescription(inventory.getItemDesc("fd1"));
      tempVector.addElement((Object)temp21);
     }
     if(zip1.length()>0)
     {
      Item temp22 = new Item();
      int qty = (new Integer(zip1)).intValue();
      float basePrice =
      inventory.getItemPrice(inventory.getInventory("zip1"));
      temp22.setPrice(basePrice*(float)qty);
      temp22.setQuantity(qty);
      temp22.setType("zip1");
      temp22.setDescription(inventory.getItemDesc("zip1"));
      tempVector.addElement((Object)temp22);
     }
     if(nic1.length()>0)
     {
      Item temp23 = new Item();
      int qty = (new Integer(nic1)).intValue();
      float basePrice =
      inventory.getItemPrice(inventory.getInventory("nic1"));
      temp23.setPrice(basePrice*(float)qty);
      temp23.setQuantity(qty);
      temp23.setType("nic1");
      temp23.setDescription(inventory.getItemDesc("nic1"));
      tempVector.addElement((Object)temp23);
     }
     if(nic2.length()>0)
     {
      Item temp24 = new Item();
      int qty = (new Integer(nic2)).intValue();
      float basePrice =
      inventory.getItemPrice(inventory.getInventory("nic2"));
      temp24.setPrice(basePrice*(float)qty);
      temp24.setQuantity(qty);
      temp24.setType("nic2");
      temp24.setDescription(inventory.getItemDesc("nic2"));
      tempVector.addElement((Object)temp24);
     }
     if(speaker1.length()>0)
     {
      Item temp25 = new Item();
      int qty = (new Integer(speaker1)).intValue();
      float basePrice =
      inventory.getItemPrice(inventory.getInventory("speaker1"));
      temp25.setPrice(basePrice*(float)qty);
      temp25.setQuantity(qty);
      temp25.setType("speaker1");
      temp25.setDescription(inventory.getItemDesc("speaker1"));
      tempVector.addElement((Object)temp25);
     }
     if(speaker2.length()>0)
     {
      Item temp26 = new Item();
      int qty = (new Integer(speaker2)).intValue();
      float basePrice =
      inventory.getItemPrice(inventory.getInventory("speaker2"));
      temp26.setPrice(basePrice*(float)qty);
      temp26.setQuantity(qty);
      temp26.setType("speaker2");
      temp26.setDescription(inventory.getItemDesc("speaker2"));
      tempVector.addElement((Object)temp26);
     }
     if(os1.length()>0)
     {
      Item temp27 = new Item();
      int qty = (new Integer(os1)).intValue();
      float basePrice =
      inventory.getItemPrice(inventory.getInventory("os1"));
      temp27.setPrice(basePrice*(float)qty);
      temp27.setQuantity(qty);
      temp27.setType("os1");
      temp27.setDescription(inventory.getItemDesc("os1"));
      tempVector.addElement((Object)temp27);
     }
     if(os2.length()>0)
     {
      Item temp28 = new Item();
      int qty = (new Integer(os2)).intValue();
      float basePrice =
      inventory.getItemPrice(inventory.getInventory("os2"));
      temp28.setPrice(basePrice*(float)qty);
      temp28.setQuantity(qty);
      temp28.setType("os2");
      temp28.setDescription(inventory.getItemDesc("os2"));
      tempVector.addElement((Object)temp28);
     }

    }// end else statement
   }
   catch(NumberFormatException nfe)
   {
     out.println("<p>You have input an invalid number. Press " +
                 "BACK button on the browser to go back to the"+
                 " previous page and try again. </p>");
     out.println(nfe);
     tempVector.removeAllElements();
     return tempVector;
   }

   return tempVector;
 }

/**
 * fillDB's method is to fill up the database with
 * the given information. If error occurs, it will
 * return value 1. The error itself will be handle in the
 * grandparent's of the calling method.
 * @param  Connection connection (connection to database)
 *         String equipPart for computer parts
 *         String equipLaptop for laptop
 *         String equipWorkst for workstation
 *         String fillOrder for filling up info into myorder
 *         String fillTrack for fillup up info into myequipt
 *         int flag for differential 1 = workstation
 *                                   2 = laptop
 *                                   3 = computer parts
 * @return none
 */
 public void fillDB(Connection connection,
	 	    String equipPart,
	            String equipLaptop,
	   	    String equipWorkst,
		    String fillOrder,
		    String fillTrack,
		    HttpServletResponse response,
		    int flag) 
                    throws IOException, SQLException
 {

    Statement stmt = connection.createStatement();

    if(flag!=2) // flag == 1 or 3
    { 
     stmt.executeUpdate(equipPart);
     if(flag == 1)
      stmt.executeUpdate(equipWorkst);
    }
    else // flag == 2 -> laptop order
     stmt.executeUpdate(equipLaptop);

   stmt.executeUpdate(fillOrder);
   stmt.executeUpdate(fillTrack);

 } // end of fillDB


}//end Order.java class

