
import java.sql.*;
import java.io.*;
import java.util.*;
import javax.servlet.*;
import javax.servlet.http.*;

public class ProcessUpload extends HttpServlet
{
 public void doGet(HttpServletRequest request,
                   HttpServletResponse response)
                   throws ServletException, IOException
 {
  doPost(request,response);
 } 

 public void doPost(HttpServletRequest request,
                    HttpServletResponse response)
                    throws ServletException, IOException
 {
  String buff = null;
  String line = null;
  String name = null;
  String filename = null;

  response.setContentType("text/html");

  PrintWriter out = response.getWriter();
  String contentType = request.getContentType();
  int boundaryIndex = contentType.indexOf("boundary=");
  String boundary = "--" + contentType.substring(boundaryIndex+9);

  ServletInputStream servIn = request.getInputStream();
  BufferedInputStream buffIn = new BufferedInputStream(servIn);

  // loop to the upload file field, "filename" is its field name
  line = readLine(buffIn);
  while (true) {
    if (line.length() == 0) {  // ensure valid field is existed
      out.println("Upload file field not found");
      return;
    }
    name = getName(line);
    if (name != null && name.compareToIgnoreCase("filename") == 0) {
      filename = getFilename(line);
      break;
    }
    line = readLine(buffIn);
  }

  readLine(buffIn);  // remove 3rd line (content-type)
  line = readLine(buffIn);  // remove the 4th line, if existed
                            // (content-transfer-encoding); else it's a '\n'
  if (line.toLowerCase().startsWith("content-transfer-encoding"))
    readLine(buffIn);  // remove extra new line

  if (filename != null) {
    if (filename.toLowerCase().endsWith(".txt"))
      buff = readTXTFile(buffIn);
    else if (filename.toLowerCase().endsWith(".html") ||
             filename.toLowerCase().endsWith(".htm"))
      buff = readHTMLFile(buffIn);
    else {
      if (filename.length() == 0)
        out.println("You need to select a file to send");
      else
        out.println("File type not support");
      return;
    }
  }
  else {
    out.println("You need to select a file to send 2");
    return;
  }

  // buff is what you want to store to db, just include it in the sql stmt
  //   as a normal string
  buff = buff.substring(0, buff.indexOf(boundary));
  buff = buff.substring(0, buff.lastIndexOf('\n'));  // remove extra new line

  out.println(buff);
 } // end of doPost's method


 private String getName(String line) {
   String name = null;
   int start;
   int end;

   if (line.toLowerCase().startsWith("content-disposition:")) {
     start = line.indexOf("; name=\"");
     end = line.indexOf("\"", start + 8);
     if (start < 0)
       return null;
     name = line.substring(start + 8, end);
   }

   return name;
 }


 private String getFilename(String line) {
   String filename = null;
   int start;
   int end;
   int slash;

   if (line.toLowerCase().startsWith("content-disposition:")) {
     start = line.indexOf("filename=\"");
     end = line.indexOf("\"", start + 10);
     if (start < 0)
       return null;
     filename = line.substring(start + 10, end);
     slash = filename.lastIndexOf('\\');
     if (slash > -1)
       filename = filename.substring(slash + 1);
   }

   return filename;
 }


 private String readLine(InputStream in) throws IOException {
   StringBuffer sbuff = new StringBuffer();
   int ch = in.read();
   while (ch != -1 && ch != '\n') {
     sbuff.append((char) ch);
     ch = in.read();
   }
   int len = sbuff.length();
   if (len > 1 && sbuff.charAt(len - 2) == '\r')
     sbuff.deleteCharAt(len - 2);
   return sbuff.toString();
 }


 private String readTXTFile(InputStream in) throws IOException {
   StringBuffer sbuff = new StringBuffer();
   int ch = in.read();
   while (ch != -1) {
     if ((char) ch == '\n') {
       if (sbuff.charAt(sbuff.length() - 1) == '\r')
	 sbuff.deleteCharAt(sbuff.length() - 1);
       sbuff.append((char) ch + "<br>");
     }
     else
       sbuff.append((char) ch);
     ch = in.read();
   }
   return sbuff.toString();
 }


 private String readHTMLFile(InputStream in) throws IOException {
   StringBuffer sbuff = new StringBuffer();
   int ch = in.read();
   while (ch != -1) {
     if ((char) ch == '\n' && sbuff.charAt(sbuff.length() - 1) == '\r')
       sbuff.deleteCharAt(sbuff.length() - 1);
     sbuff.append((char) ch);
     ch = in.read();
   }
   return sbuff.toString();
 }

} // end of ProcessUpload 
